/*
    comedi_config/comedi_config.c
    configuration program for comedi kernel module

    COMEDI - Linux Control and Measurement Device Interface
    Copyright (C) 1998 David A. Schleef <ds@stm.lbl.gov>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/


#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <sys/ioctl.h>
#include <stdio.h>
#include <comedi.h>
#include <getopt.h>
#include <errno.h>
#include <../module/comedi_module.h>
#include <string.h>

int quiet=0,verbose=0,script=0;

void do_script(void);

void do_help(int i)
{
	fputs(
"comedi_config version " COMEDI_VERSION "\n"
"usage:\n"
"  comedi_config [-[vVq]] <device file> <driver> <option1>,<option2>,...\n"
"where <optionN> are integers (or blank) whose interpretation depends on\n"
"the driver.  In general, however, option1 refers to the I/O port address\n"
"and option2 refers to IRQ number to be used by the driver\n"
		,stderr);
	exit(i);
}

int main(int argc,char *argv[])
{
	comedi_devconfig it;
	int fd;
	int c,i,num,k;
	char *opts;
	char *fn,*driver;
	
	while(1){
		c=getopt(argc,argv,"vVq");
		if(c==-1)break;
		switch(c){
		case 'v':
			verbose=1;
			break;
		case 'V':
			fputs("comedi_config version " COMEDI_VERSION "\n",stderr);
			exit(0);
			break;
		case 'q':
			quiet=1;
			break;
		case 'a':
			script=1;
			break;
		default:
			do_help(1);
		}
	}
	if(script)do_script();
	if(optind>=argc)do_help(0);
	fn=argv[optind];
	optind++;
	if(optind>=argc){
		puts("Info not available");
		exit(0);
	}
	driver=argv[optind];
	strncpy(it.name,driver,COMEDI_NAMELEN);
	optind++;

	for(i=0;i<COMEDI_NDEVCONFOPTS;i++)it.options[i]=0;

	opts=argv[optind];
	i=0;
	while(*opts){
		if((*opts)==','){
			i++;
			opts++;
			continue;
		}
		if(sscanf(opts,"%i%n",&num,&k)){
			it.options[i]=num;
			opts+=k;
			continue;
		}
		do_help(0);
	}
	
	fd=open(fn,O_RDWR);
	if(fd<0){
		perror(fn);
		exit(1);
	}
	/* add: sanity check for device */
	
if(verbose){
	printf("configuring driver=%s ",it.name);
	for(i=0;i<COMEDI_NDEVCONFOPTS;i++)printf("%d,",it.options[i]);
	printf("\n");
}
	if(ioctl(fd,COMEDI_CONFIG,&it)<0){
		perror("Configure failed!");
		exit(1);
	}
	exit(0);
}

void do_script(void)
{
	printf("comedi_config: -a option not supported (yet).\n");
	exit(0);
}

